@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from ormlambda import Table
-    from ormlambda import IRepositoryBase
+    from ormlambda.repository import IRepositoryBase
 
 from ormlambda.common.abstract_classes import NonQueryBase
 from .IInsert import IInsert
